@@ -21,6 +21,11 @@
 ##
 
 
+#--------------------------------------------------------------------------------------
+import cloudflu.common as common
+from cloudflu.common import print_d, print_e
+
+
 #--------------------------------------------------------------------------------------
 def create_test_file( the_size ) :
     import tempfile
@@ -79,7 +84,7 @@ class SeedSizeMesurement :
 
         #---------------------------- Estimate the timeout value ------------------------------
         self._timeout = measure_time( self._bucket, the_initial_size )
-        print "timeout (true) = %3.2f, sec" % ( self._timeout )
+        print_d( "timeout (true) = %3.2f, sec\n" % ( self._timeout ) )
 
         self.set_number_threads( the_number_threads )
         pass
@@ -94,7 +99,7 @@ class SeedSizeMesurement :
     def set_number_threads( self, the_value ):
         self._number_threads = the_value
         a_timeout = self._timeout * self._number_threads
-        print "timeout (efficient) = %3.2f, sec" % ( a_timeout )
+        print_d( "timeout (efficient) = %3.2f, sec\n" % ( a_timeout ) )
 
         import socket
         socket.setdefaulttimeout( a_timeout )
@@ -137,7 +142,7 @@ class SeedSizeMesurement :
       
       a_count_non_zero = self._number_threads - a_speeds.count( 0 )
       a_speed = ( ( float( a_count_non_zero ) * the_filesize * 8 ) / float( a_time ) ) / 1024
-      print "%4d - {%s} : %4.2f = %4.2f " % ( the_filesize, a_string, a_time, a_speed )
+      print_d( "%4d - {%s} : %4.2f = %4.2f\n" % ( the_filesize, a_string, a_time, a_speed ) )
       
       return a_speed
       
@@ -191,7 +196,7 @@ def measure_time( the_bucket, the_filesize ):
 
 #--------------------------------------------------------------------------------------
 def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY ):
-    print "looking for \"best\" region ..."
+    print_d( "looking for \"best\" region ...\n" )
     a_regions = [ '', 'EU', 'ap-southeast-1', 'us-west-1' ]
     
     a_test_filesize = 8192
@@ -220,7 +225,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
     for a_region in a_regions:
         an_averagespeed = a_region2sum_speeds[ a_region ] / float( the_nb_attempts )
         average_speed2region[ an_averagespeed ] = a_region
-        print " region \'%s\' : %4.0f kbs"  % ( a_region, an_averagespeed )
+        print_d( " region \'%s\' : %4.0f, kbs\n"  % ( a_region, an_averagespeed ) )
         delete_object( a_region2bucket[ a_region ] ) 
         pass
     
@@ -235,7 +240,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
        a_full_name = "us-east-1 ( \'\' )"
        pass
     
-    print "\nfastest region - \"%s\"\n" % a_full_name
+    print_d( "\nfastest region - \"%s\"\n\n" % a_full_name )
 
     a_first_stats = {}
     a_first_stats[ a_test_filesize ] = a_region2speeds[ a_region ] # further, we use this values
@@ -273,7 +278,7 @@ def print_dict( the_x2y ) :
     a_xs.sort()
     for a_x in a_xs :
         a_values_string = create_values_string( the_x2y[ a_x ] )
-        print "%4d : %s" % ( a_x, a_values_string )
+        print_d( "%4d : %s\n" % ( a_x, a_values_string ) )
         pass
     pass
 
@@ -287,13 +292,13 @@ def print2_dict( the_sub_xs, the_x2y ) :
     a_xs.sort()
     for a_x in a_xs :
         if a_x in the_sub_xs :
-            print " + ", 
+            print_d( " + " )
         else:
-            print " - ", 
+            print_d( " - " )
             pass
 
         a_values_string = create_values_string( the_x2y[ a_x ] )
-        print "%4d : %s" % ( a_x, a_values_string )
+        print_d( "%4d : %s\n" % ( a_x, a_values_string ) )
 
         a_counter += 1
         pass
@@ -389,7 +394,7 @@ def find_center( the_x2y, the_sub2_nb_attempts ) :
         pass
 
     a_center_x = a_xs[ an_average_y_index ]
-    print "center : [ %4d ] = %4d\n" % ( a_center_x, a_max_average_y )    
+    print_d( "center : [ %4d ] = %4d\n\n" % ( a_center_x, a_max_average_y ) )
     
     return a_center_x, a_max_average_y
 
@@ -418,7 +423,7 @@ def get_stats( the_fun, the_x2y, the_cost, the_center_x, the_region_x, the_nb_at
         an_area = an_end_x - a_start_x
         pass
 
-    print "[ %4d - %4d ] : " % ( a_start_x, an_end_x )
+    print_d( "[ %4d - %4d ] :\n" % ( a_start_x, an_end_x ) )
 
     a_sub_xs = []
     a_x = an_end_x
@@ -431,7 +436,7 @@ def get_stats( the_fun, the_x2y, the_cost, the_center_x, the_region_x, the_nb_at
         pass
 
     print2_dict( a_sub_xs, the_x2y )
-    print "cost : %4d\n" % the_cost
+    print_d( "cost : %4d\n\n" % the_cost )
 
     return the_x2y, the_cost, an_area
 
@@ -443,7 +448,7 @@ def calculate_optimal_number_threads( the_fun, the_seed_size, the_precision, the
     a_start_speed = 0.0
     a_cost = 0
     while True:
-        print "number threads : %d" % a_nb_threads
+        print_d( "number threads : %d\n" % a_nb_threads )
         the_fun.set_number_threads( a_nb_threads )
         a_speed = 0.0
         for an_attempt in range( the_nb_attempts ) :
@@ -452,7 +457,7 @@ def calculate_optimal_number_threads( the_fun, the_seed_size, the_precision, the
             pass
         
         a_speed /= float( the_nb_attempts )
-        print "speed : %4d\n" % a_speed
+        print_d( "speed : %4d\n\n" % a_speed )
 
         import math
         if a_speed < a_start_speed or math.fabs( a_speed - a_start_speed ) / a_speed < a_precision:
@@ -502,7 +507,7 @@ def calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, the_precis
     like a dog; you need to give him a good hook first to make sure that he understood what you are looking for ).
     """
     a_center_x = the_center_x
-    print "%4d - %4d\n" % ( a_center_x, 0.0 )
+    print_d( "%4d - %4d\n\n" % ( a_center_x, 0.0 ) )
     a_sub_nb_attempts = the_nb_attempts / 1
     a_cost = 0.0
     a_x2y = the_x2y
@@ -532,7 +537,7 @@ def calculate_optimal_seed_size( the_fun, the_center_x, the_region_x, the_precis
 
     #------------------------------------------------------------------------------------------
     an_optimize_x = a_center_x
-    print "solution : %4d / cost : %4d\n" % ( an_optimize_x, a_cost )
+    print_d( "solution : %4d / cost : %4d\n\n" % ( an_optimize_x, a_cost ) )
 
     return an_optimize_x, a_cost
 
@@ -624,10 +629,14 @@ def main() :
     
     amazon.security_options.add( an_option_parser )
 
+    common.options.add( an_option_parser )
+
     
     #------------------ Extracting and verifying command-line arguments ----------------------
     an_options, an_args = an_option_parser.parse_args()
 
+    common.options.extract( an_option_parser )
+
     AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY = amazon.security_options.extract( an_option_parser )
 
     a_precision = an_options.precision
@@ -669,7 +678,7 @@ def main() :
     import os; os.system( "perl -p -i -e 's/(upload_seed_size =)\s*[0-9]+/\\1 %d/' %s" % 
                           ( an_optimize_x, an_rcfilename ) )
 
-    print "a_spent_time = %s, sec\n" % a_spent_time
+    print_d( "a_spent_time = %s, sec\n" % a_spent_time )
     pass
 
 
